# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-Pod-Eventual
Version:	0.094001
Release:	5.%{__distinit}%{__distvers}
Summary:	Read a POD document as a series of trivial events
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Pod-Eventual/
Source0:	http://search.cpan.org/CPAN/authors/id/R/RJ/RJBS/Pod-Eventual-%{version}.tar.gz
Patch0:		Pod-Eventual-0.094001-old-Test::More.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.30
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Mixin::Linewise::Readers) >= 0.102
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Test::Deep)
BuildRequires:	perl(Test::More) >= 0.47
# Extra Tests
BuildRequires:	perl(Test::Pod) >= 1.41
# Dependencies
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
POD is a pretty simple format to write, but it can be a big pain to deal
with reading it and doing anything useful with it. Most existing POD
parsers care about semantics, like whether a =item occurred after an
=over but before a back, figuring out how to link a L<>, and other things
like that.

Pod::Eventual is much less ambitious and much more stupid. Fortunately, stupid
is often better (that's what I keep telling myself, anyway).

Pod::Eventual reads line-based input and produces events describing each POD
paragraph or directive it finds. Once complete events are immediately passed to
the handle_event method. This method should be implemented by Pod::Eventual
subclasses. If it isn't, Pod::Eventual's own handle_event will be called, and
will raise an exception.

%prep
%setup -q -n Pod-Eventual-%{version}

# We need to patch the test suite if we have an old version of Test::More
%if %{old_test_more}
%patch0
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes README
%{perl_vendorlib}/Pod/
%{_mandir}/man3/Pod::Eventual.3*
%{_mandir}/man3/Pod::Eventual::Simple.3*

%changelog
* Wed Sep 21 2016 Paul Howarth <paul@city-fan.org> - 0.094001-5
- Classify buildreqs by usage
- Simplify find command using -delete

* Wed Sep 10 2014 Paul Howarth <paul@city-fan.org> - 0.094001-2
- Drop %%defattr, redundant since rpm 4.4
- Drop support for building with ExtUtils::MakeMaker < 6.30
- Use %%license where possible

* Wed Nov  6 2013 Paul Howarth <paul@city-fan.org> - 0.094001-1
- Update to 0.094001
  - Require Mixin-Linewise 0.102 to avoid busted 0.101

* Sun Oct 20 2013 Paul Howarth <paul@city-fan.org> - 0.094000-1
- Update to 0.094000
  - Tiny documentation tweak

* Sun Oct 13 2013 Paul Howarth <paul@city-fan.org> - 0.093331-1
- Update to 0.093331
  - Update repo and bug tracker
- Add patches to support building with ExtUtils::MakeMaker < 6.30 and
  Test::More < 0.94
- Explicitly run the extra tests

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 0.093330-10
- Perl 5.16 post-bootstrap rebuild

* Fri Jul  6 2012 Paul Howarth <paul@city-fan.org> - 0.093330-9
- BR: perl(Carp)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Always use Test::Deep
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Sat Jul  2 2011 Paul Howarth <paul@city-fan.org> - 0.093330-6
- Rebuild for perl 5.14.1 in Rawhide
- Add support for perl_bootstrap macro
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 0.093330-5
- Rebuild for perl 5.12.1 in Rawhide

* Tue May 11 2010 Paul Howarth <paul@city-fan.org> - 0.093330-4
- Fix dist tag for RHEL-6 Beta

* Wed Feb  3 2010 Paul Howarth <paul@city-fan.org> - 0.093330-3
- BR: perl(Pod::Coverage::TrustPod) for extra test cover (note that this
  introduces a build dependency loop that will need to be worked around if
  bootstrapping new releases)

* Wed Feb  3 2010 Paul Howarth <paul@city-fan.org> - 0.093330-2
- Import from Fedora
- Add patch to support build on Perl 5.8.0 where we have no Test::Deep

* Thu Jan 14 2010 Iain Arnell 0.093330-1
- Specfile autogenerated by cpanspec 1.78
